==> humhub-1.6.4.tar.gz: humhub-1.6.4/protected/humhub/modules/installer/messages/hr/base.php <==
<?php
return array (
  '<strong>Admin</strong> Account' => '<strong>Admin</strong> račun',
  '<strong>Configuration</strong>' => '<strong>Konfiguracija</strong>',
  '<strong>Congratulations</strong>. You\'re done.' => '<strong>Čestitamo</strong>. Završili ste.',
  '<strong>Database</strong> Configuration' => '<strong>Baza podataka</strong> - konfiguracija',
  '<strong>Example</strong> contents' => '<strong>Primjer</strong> sadržaj',
  '<strong>System</strong> Check' => '<strong>Sistem</strong> provjera',
  '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Dobrodošli</strong> u HumHub<br> Vaš toolbox za društvenu mrežu',
  'Allow access for non-registered users to public content (guest access)' => 'Dopusti pristup neprijavljenim korisnicima javnim sadržajima (gost pristup)',
  'Allow friendships between members' => 'Dopustite prijateljstva među članovima',
  'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'U nastavku morate unijeti pojedinosti veze s bazom podataka. Ako niste sigurni u njih, obratite se administratoru sustava.',
  'Calvin Klein – Between love and madness lies obsession.' => 'Calvin Klein – Between love and madness lies obsession.',
  'Check again' => 'Provjeri ponovno',
  'Congratulations! Everything is ok and ready to start over!' => 'Čestitamo! Sve je u redu i spremno za početak!',
  'Create Admin Account' => 'Kreiraj Admin račun',
  'Downloading & Installing Modules...' => 'Preuzimanje i instaliranje modula...',
  'External users can register (show registration form on login)' => 'Vanjski korisnici mogu se registrirati (prikazati obrazac za registraciju pri prijavi)',
  'Here you can decide how new, unregistered users can access HumHub.' => 'Ovdje možete odlučiti kako novi, neregistrirani korisnici mogu pristupiti HumHubu.',
  'Hostname' => 'Hostname',
  'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Naziv hosta MySQL baza podataka poslužitelja (npr. Localhost ako MySQL radi na istom stroju)',
  'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub je vrlo fleksibilan i može se prilagoditi i / ili proširiti za različite primjene zahvaljujući različitim modulima. Sljedeći moduli samo su neki od primjera, tj. oni koje smo smatrali najvažnije za odabranu aplikaciju. <br> <br> Uvijek možete instalirati ili ukloniti module kasnije. Više dostupnih modula možete pronaći nakon instalacije u području administracije.',
  'I want to use HumHub for:' => 'Želim koristiti HumHub za:',
  'Initializing database...' => 'Inicijaliziranje baze podataka...',
  'My club' => 'Moj klub',
  'My community' => 'Moja zajednica',
  'My company (Social Intranet / Project management)' => 'Moja kompanija (Društveni intranet/ Projektni menadžment)',
  'My educational institution (school, university)' => 'Moja edukacijska ustanova (škola, fakultet)',
  'Name of Database' => 'Ime baze podataka',
  'Name of your network' => 'Naziv vaše mreže',
  'Newly registered users have to be activated by an admin first' => 'Novo registrirani korisnici moraju biti aktivirani od strane administratora',
  'Next' => 'Dalje',
  'Nike – Just buy it. ;Wink;' => 'Nike – Just buy it. ;Wink;',
  'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Naravno, vaša nova društvena mreža treba ime. Promijenite zadani naziv s onim koji vam se sviđa. (Na primjer, ime vaše tvrtke, organizacije ili kluba)',
  'Ohh, something went wrong!' => 'Uh, nešto je pošlo po krivu!',
  'Password' => 'Lozinka',
  'Recommended <strong>Modules</strong>' => 'Preporučeni <strong>Moduli</strong>',
  'Registered members can invite new users via email' => 'Registrirani članovi mogu pozvati nove korisnike putem e-pošte',
  'Security <strong>Settings</strong>' => 'Sigurnosne <strong>postavke</strong>',
  'Set up example content (recommended)' => 'Postavi primjer sadržaja (preporučeno)',
  'Sign in' => 'Prijavi se',
  'Skip this step, I want to set up everything manually' => 'Preskoči ovaj korak, želim sve namjestiti ručno',
  'Social Network <strong>Name</strong>' => 'Društvena mreža <strong>Ime</strong>',
  'The installation completed successfully! Have fun with your new social network.' => 'Instalacija je uspješno završila! Zabavite se s vašom novom društvenom mrežom.',
  'The name of the database you want to run HumHub in.' => 'Ime baze podataka u kojoj želite imati HumHub.',
  'This overview shows all system requirements of HumHub.' => 'Ovaj pregled prikazuje sve zahtjeve sustava HumHub.',
  'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Ovaj će čarobnjak instalirati i konfigurirati vašu vlastitu instancu HumHub. <br> <br> Da biste nastavili, kliknite Dalje.',
  'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'Da biste izbjegli praznu upravljačku ploču nakon početnog prijavljivanja, HumHub može instalirati primjer sadržaja za vas. Oni će vam dati lijep opći prikaz kako HumHub radi. Uvijek možete izbrisati pojedinačne sadržaje.',
  'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Da bismo pojednostavili konfiguraciju, imamo predefinirane postavke za najčešće korištene slučajeve s različitim opcijama za module i postavke. Možete ih prilagoditi tijekom sljedećeg koraka.',
  'Username' => 'Korisničko ime',
  'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Tražimo super slogane poznatih brendova. Možda se možete sjetti nekih primjera.',
  'Welcome Space' => 'Prostor dobrodošlice',
  'Yay! I\'ve just installed HumHub ;Cool;' => 'Jupi! Upravo instaliran HumHub ;Cool;',
  'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Skoro si gotov. U ovom koraku morate ispuniti obrazac za izradu računa administratora. Pomoću ovog računa možete upravljati cijelom mrežom.',
  'Your MySQL password.' => 'Vaša MySQL lozinka.',
  'Your MySQL username' => 'Vaše MySQL korisničko ime',
  'Your first sample space to discover the platform.' => 'Vaš prvi primjer prostora za otkrivanje platforme.',
);

==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/installer/messages/hr/base.php <==
<?php
return array (
  '<strong>Admin</strong> Account' => '<strong>Admin</strong> račun',
  '<strong>Configuration</strong>' => '<strong>Konfiguracija</strong>',
  '<strong>Congratulations</strong>. You\'re done.' => '<strong>Čestitamo</strong>. Završili ste.',
  '<strong>Database</strong> Configuration' => '<strong>Baza podataka</strong> - konfiguracija',
  '<strong>Example</strong> contents' => '<strong>Primjer</strong> sadržaj',
  '<strong>System</strong> Check' => '<strong>Sistem</strong> provjera',
  '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Dobrodošli</strong> u HumHub<br> Vaš toolbox za društvenu mrežu',
  'Allow access for non-registered users to public content (guest access)' => 'Dopusti pristup neprijavljenim korisnicima javnim sadržajima (gost pristup)',
  'Allow friendships between members' => 'Dopustite prijateljstva među članovima',
  'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'U nastavku morate unijeti pojedinosti veze s bazom podataka. Ako niste sigurni u njih, obratite se administratoru sustava.',
  'Calvin Klein – Between love and madness lies obsession.' => 'Calvin Klein – Between love and madness lies obsession.',
  'Check again' => 'Provjeri ponovno',
  'Congratulations! Everything is ok and ready to start over!' => 'Čestitamo! Sve je u redu i spremno za početak!',
  'Create Admin Account' => 'Kreiraj Admin račun',
  'Downloading & Installing Modules...' => 'Preuzimanje i instaliranje modula...',
  'External users can register (show registration form on login)' => 'Vanjski korisnici mogu se registrirati (prikazati obrazac za registraciju pri prijavi)',
  'Here you can decide how new, unregistered users can access HumHub.' => 'Ovdje možete odlučiti kako novi, neregistrirani korisnici mogu pristupiti HumHubu.',
  'Hostname' => 'Hostname',
  'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Naziv hosta MySQL baza podataka poslužitelja (npr. Localhost ako MySQL radi na istom stroju)',
  'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub je vrlo fleksibilan i može se prilagoditi i / ili proširiti za različite primjene zahvaljujući različitim modulima. Sljedeći moduli samo su neki od primjera, tj. oni koje smo smatrali najvažnije za odabranu aplikaciju.<br><br>Uvijek možete instalirati ili ukloniti module kasnije. Više dostupnih modula možete pronaći nakon instalacije u području administracije.',
  'I want to use HumHub for:' => 'Želim koristiti HumHub za:',
  'Initializing database...' => 'Inicijaliziranje baze podataka...',
  'My club' => 'Moj klub',
  'My community' => 'Moja zajednica',
  'My company (Social Intranet / Project management)' => 'Moja kompanija (Društveni intranet/ Projektni menadžment)',
  'My educational institution (school, university)' => 'Moja edukacijska ustanova (škola, fakultet)',
  'Name of Database' => 'Ime baze podataka',
  'Name of your network' => 'Naziv vaše mreže',
  'Newly registered users have to be activated by an admin first' => 'Novo registrirani korisnici moraju biti aktivirani od strane administratora',
  'Next' => 'Dalje',
  'Nike – Just buy it. :wink:' => 'Nike – Just buy it. :wink:',
  'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Naravno, vaša nova društvena mreža treba ime. Promijenite zadani naziv s onim koji vam se sviđa. (Na primjer, ime vaše tvrtke, organizacije ili kluba)',
  'Ohh, something went wrong!' => 'Uh, nešto je pošlo po krivu!',
  'Password' => 'Lozinka',
  'Recommended <strong>Modules</strong>' => 'Preporučeni <strong>Moduli</strong>',
  'Registered members can invite new users via email' => 'Registrirani članovi mogu pozvati nove korisnike putem e-pošte',
  'Security <strong>Settings</strong>' => 'Sigurnosne <strong>postavke</strong>',
  'Set up example content (recommended)' => 'Postavi primjer sadržaja (preporučeno)',
  'Sign in' => 'Prijavi se',
  'Skip this step, I want to set up everything manually' => 'Preskoči ovaj korak, želim sve namjestiti ručno',
  'Social Network <strong>Name</strong>' => 'Društvena mreža <strong>Ime</strong>',
  'The installation completed successfully! Have fun with your new social network.' => 'Instalacija je uspješno završila! Zabavite se s vašom novom društvenom mrežom.',
  'The name of the database you want to run HumHub in.' => 'Ime baze podataka u kojoj želite imati HumHub.',
  'This overview shows all system requirements of HumHub.' => 'Ovaj pregled prikazuje sve zahtjeve sustava HumHub.',
  'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Ovaj će čarobnjak instalirati i konfigurirati vašu vlastitu instancu HumHub.<br><br>Da biste nastavili, kliknite Dalje.',
  'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'Da biste izbjegli praznu upravljačku ploču nakon početnog prijavljivanja, HumHub može instalirati primjer sadržaja za vas. Oni će vam dati lijep opći prikaz kako HumHub radi. Uvijek možete izbrisati pojedinačne sadržaje.',
  'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Da bismo pojednostavili konfiguraciju, imamo predefinirane postavke za najčešće korištene slučajeve s različitim opcijama za module i postavke. Možete ih prilagoditi tijekom sljedećeg koraka.',
  'Username' => 'Korisničko ime',
  'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Tražimo super slogane poznatih brendova. Možda se možete sjetti nekih primjera.',
  'Welcome Space' => 'Prostor dobrodošlice',
  'Yay! I\'ve just installed HumHub :sunglasses:' => 'Jupi! Upravo instaliran HumHub :sunglasses:',
  'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Skoro si gotov. U ovom koraku morate ispuniti obrazac za izradu računa administratora. Pomoću ovog računa možete upravljati cijelom mrežom.',
  'Your MySQL password.' => 'Vaša MySQL lozinka.',
  'Your MySQL username' => 'Vaše MySQL korisničko ime',
  'Your first sample space to discover the platform.' => 'Vaš prvi primjer prostora za otkrivanje platforme.',
);
